@@ -1,7 +1,7 @@
 '''
 Main module for uniprot-dl.
 '''
-from dispatcher import dispatch_and_run
+from .dispatcher import dispatch_and_run
 
 
 def main():
