@@ -1,6 +1,8 @@
 '''Functionality for fetching individual proteins in various formats.'''
 
+import sys
 import requests
+import .data_sources as ds
 
 UNIPROT_URL = 'http://uniprot.org/uniprot/'
 
@@ -15,20 +17,10 @@ class UnknownDataSetError(BaseException):
     '''Exception for when trying to query from an invalid data set.'''
 
 
-def fetch(uid: str, data_format='fasta', dataset='default'):
-    '''Downloads the protein sequence from uniprot as a .fasta file.'''
-    response = requests.get(UNIPROT_URL + uid + '.fasta')
-
-    if response.status_code != 200:
-        raise EntryNotFoundException()
-
-    return response.content.decode()
-
-
 def format_url(uid: str, data_format='fasta', dataset='default'):
     if dataset == 'default':
         return UNIPROT_URL + uid + '/.' + data_format
-    elif dataset in ['uniprotkb', 'uniref', 'uniparc']:
+    elif dataset in ds.KNOWN_DATASETS:
         return BASE_API_URL + dataset + '/' + uid + '/.' + data_format 
     else:
         raise UnknownDataSetError()
@@ -37,7 +29,7 @@ def format_url(uid: str, data_format='fasta', dataset='default'):
 def fetch(uid: str, data_format='fasta', dataset='default'):
     '''Downloads the protein sequence from uniprot as a .fasta file.'''
     try:
-        url = get_url(uid, data_format, dataset)
+        url = format_url(uid, data_format, dataset)
     except UnknownDataSetError:
         print(f"Error - Data set: {dataset} is unknown to uniprot.")
         sys.exit(-1)
